import requests
from bs4 import BeautifulSoup

"""
berita terkini dari laman kemendikbud
"""

def ekstraksi_data():
    try:
        content = requests.get('https://kemdikbud.go.id/main/blog/category/berita')
    except Exception:
        return None
    if content.status_code == 200:
        soup = BeautifulSoup(content.text, 'html.parser')
        #print(soup.prettify())
        judul = soup.find('strong')
        judul = judul.text

        waktu = soup.find('span', {'class': 'date'})
        waktu = waktu.text.split(', ')
        tanggal = waktu[0]

        hasil = dict()
        hasil ['judul'] = judul
        hasil ['waktu'] = tanggal

        return hasil


def tampilkan_hasil(result):
    print('Berita Terkini dari Laman Kemendikbud')
    print(f"Judul Berita ={result['judul']}")
    print(f"Waktu Terbit ={result['waktu']}")

if __name__ == '__main__':
    result = ekstraksi_data()
    tampilkan_hasil(result)


"""
https://packaging.python.org/en/latest/tutorials/packaging-projects/
"""

import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="latestnews-kemendikbud",
    version="0.0.2",
    author="Irfan Basyar",
    author_email="irfanbasyar.ib@gmail.com",
    description="this package will get the latest news from Indonesian Ministry of Education and Culture (Kemdikbud)",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/dikopini/latest-kemendikbud-news",
    project_urls={
        "Website": "https://dicopynee.com",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
        "Development Status :: 4 - Beta"
    ],
    #package_dir={"": "src"},
    #packages=setuptools.find_packages(where="src"),
    packages=setuptools.find_packages(),
    python_requires=">=3.6",
)